@@ -1,7 +1,9 @@
 # Copyright 2012 by Wibowo Arindrarto.  All rights reserved.
-# This code is part of the Biopython distribution and governed by its
-# license.  Please see the LICENSE file that should have been included
-# as part of this package.
+#
+# This file is part of the Biopython distribution and governed by your
+# choice of the "Biopython License Agreement" or the "BSD 3-Clause License".
+# Please see the LICENSE file that should have been included as part of this
+# package.
 
 """Bio.SearchIO parser for BLAST+ tab output format, with or without comments."""
 
@@ -131,7 +133,8 @@ _SUPPORTED_FIELDS = set(list(_COLUMN_QRESULT) + list(_COLUMN_HIT) +
 # column order in the non-commented tabular output variant
 # values must be keys inside the column-attribute maps above
 _DEFAULT_FIELDS = ['qseqid', 'sseqid', 'pident', 'length', 'mismatch',
-        'gapopen', 'qstart', 'qend', 'sstart', 'send', 'evalue', 'bitscore']
+                   'gapopen', 'qstart', 'qend', 'sstart', 'send',
+                   'evalue', 'bitscore']
 # one field from each of the following sets must exist in order for the
 # parser to work
 _MIN_QUERY_FIELDS = set(['qseqid', 'qacc', 'qaccver'])
@@ -145,7 +148,7 @@ _RE_GAPOPEN = re.compile(r'\w-')
 
 
 def _compute_gapopen_num(hsp):
-    """Returns the number of gap openings in the given HSP."""
+    """Return the number of gap openings in the given HSP (PRIVATE)."""
     gapopen = 0
     for seq_type in ('query', 'hit'):
         seq = str(getattr(hsp, seq_type).seq)
@@ -154,7 +157,7 @@ def _compute_gapopen_num(hsp):
 
 
 def _augment_blast_hsp(hsp, attr):
-    """Calculates the given HSP attribute, for writing."""
+    """Calculate the given HSP attribute, for writing (PRIVATE)."""
     if attr == 'aln_span':
         # aln_span is number of identical matches + mismatches + gaps
         func = lambda hsp: hsp.ident_num + hsp.mismatch_num + hsp.gap_num
@@ -199,30 +202,35 @@ def _augment_blast_hsp(hsp, attr):
 
 
 class BlastTabParser(object):
-
     """Parser for the BLAST tabular format."""
 
     def __init__(self, handle, comments=False, fields=_DEFAULT_FIELDS):
+        """Initialize the class."""
         self.handle = handle
         self.has_comments = comments
         self.fields = self._prep_fields(fields)
         self.line = self.handle.readline().strip()
 
     def __iter__(self):
+        """Iterate over BlastTabParser, yields query results."""
         # stop iteration if file has no lines
         if not self.line:
-            raise StopIteration
+            return
         # determine which iterator to use
         elif self.has_comments:
             iterfunc = self._parse_commented_qresult
         else:
+            if self.line.startswith("#"):
+                raise ValueError("Encountered unexpected character '#' at the"
+                                 " beginning of a line. Set comments=True if"
+                                 " the file is a commented file.")
             iterfunc = self._parse_qresult
 
         for qresult in iterfunc():
             yield qresult
 
     def _prep_fields(self, fields):
-        """Validates and formats the given fields for use by the parser."""
+        """Validate and format the given fields for use by the parser (PRIVATE)."""
         # cast into list if fields is a space-separated string
         if isinstance(fields, basestring):
             fields = fields.strip().split(' ')
@@ -240,7 +248,7 @@ class BlastTabParser(object):
         return fields
 
     def _parse_commented_qresult(self):
-        """Iterator returning `QueryResult` objects from a commented file."""
+        """Yield `QueryResult` objects from a commented file (PRIVATE)."""
         while True:
             comments = self._parse_comments()
             if comments:
@@ -264,7 +272,7 @@ class BlastTabParser(object):
                 break
 
     def _parse_comments(self):
-        """Returns a dictionary containing tab file comments."""
+        """Return a dictionary containing tab file comments (PRIVATE)."""
         comments = {}
         while True:
             # parse program and version
@@ -305,19 +313,19 @@ class BlastTabParser(object):
                 self.line = self.line.strip()
 
     def _parse_fields_line(self):
-        """Returns a list of column short names from the 'Fields'
-        comment line."""
+        """Return column short names line from 'Fields' comment line (PRIVATE)."""
         raw_field_str = self.line[len('# Fields: '):]
         long_fields = raw_field_str.split(', ')
         fields = [_LONG_SHORT_MAP[long_name] for long_name in long_fields]
         return self._prep_fields(fields)
 
     def _parse_result_row(self):
-        """Returns a dictionary of parsed row values."""
+        """Return a dictionary of parsed row values (PRIVATE)."""
         fields = self.fields
         columns = self.line.strip().split('\t')
-        assert len(fields) == len(columns), "Expected %i columns, found: " \
-            "%i" % (len(fields), len(columns))
+        if len(fields) != len(columns):
+            raise ValueError("Expected %i columns, found: "
+                             "%i" % (len(fields), len(columns)))
 
         qresult, hit, hsp, frag = {}, {}, {}, {}
         for idx, value in enumerate(columns):
@@ -345,7 +353,7 @@ class BlastTabParser(object):
         return {'qresult': qresult, 'hit': hit, 'hsp': hsp, 'frag': frag}
 
     def _get_id(self, parsed):
-        """Returns the value used for a QueryResult or Hit ID from a parsed row."""
+        """Return the value used for a QueryResult or Hit ID from a parsed row (PRIVATE)."""
         # use 'id', with 'id_all', 'accession' and 'accession_version'
         # fallbacks one of these must have a value since we've checked whether
         # they exist or not when parsing the comments
@@ -360,7 +368,7 @@ class BlastTabParser(object):
         return id_cache
 
     def _parse_qresult(self):
-        """Generator function that returns QueryResult objects."""
+        """Yield QueryResult objects (PRIVATE)."""
         # state values, used to determine what to do with each line
         state_EOF = 0
         state_QRES_NEW = 1
@@ -422,21 +430,21 @@ class BlastTabParser(object):
                     for seq_type in ('query', 'hit'):
                         if attr == seq_type + '_start':
                             value = min(value,
-                                    prev['frag'][seq_type + '_end']) - 1
+                                        prev['frag'][seq_type + '_end']) - 1
                         elif attr == seq_type + '_end':
                             value = max(value,
-                                    prev['frag'][seq_type + '_start'])
+                                        prev['frag'][seq_type + '_start'])
                     setattr(frag, attr, value)
                 # strand and frame setattr require the full parsed values
                 # to be set first
                 for seq_type in ('hit', 'query'):
                     # try to set hit and query frame
                     frame = self._get_frag_frame(frag, seq_type,
-                            prev['frag'])
+                                                 prev['frag'])
                     setattr(frag, '%s_frame' % seq_type, frame)
                     # try to set hit and query strand
                     strand = self._get_frag_strand(frag, seq_type,
-                            prev['frag'])
+                                                   prev['frag'])
                     setattr(frag, '%s_strand' % seq_type, strand)
 
                 hsp = HSP([frag])
@@ -471,8 +479,11 @@ class BlastTabParser(object):
             self.line = self.handle.readline().strip()
 
     def _get_frag_frame(self, frag, seq_type, parsedict):
-        """Returns `HSPFragment` frame given the object, its sequence type,
-        and its parsed dictionary values."""
+        """Return fragment frame for given object (PRIVATE).
+
+        Returns `HSPFragment` frame given the object, its sequence type,
+        and its parsed dictionary values.
+        """
         assert seq_type in ('query', 'hit')
         frame = getattr(frag, '%s_frame' % seq_type, None)
         if frame is not None:
@@ -485,8 +496,11 @@ class BlastTabParser(object):
             # else implicit None return
 
     def _get_frag_strand(self, frag, seq_type, parsedict):
-        """Returns `HSPFragment` strand given the object, its sequence type,
-        and its parsed dictionary values."""
+        """Return fragment strand for given object (PRIVATE).
+
+        Returns `HSPFragment` strand given the object, its sequence type,
+        and its parsed dictionary values.
+        """
         # NOTE: this will never set the strands as 0 for protein
         # queries / hits, since we can't detect the blast flavors
         # from the columns alone.
@@ -505,12 +519,12 @@ class BlastTabParser(object):
 
 
 class BlastTabIndexer(SearchIndexer):
-
     """Indexer class for BLAST+ tab output."""
 
     _parser = BlastTabParser
 
     def __init__(self, filename, comments=False, fields=_DEFAULT_FIELDS):
+        """Initialize the class."""
         SearchIndexer.__init__(self, filename, comments=comments, fields=fields)
 
         # if the file doesn't have comments,
@@ -524,10 +538,11 @@ class BlastTabIndexer(SearchIndexer):
                 self._key_idx = fields.index('qaccver')
             else:
                 raise ValueError("Custom fields is missing an ID column. "
-                        "One of these must be present: 'qseqid', 'qacc', or 'qaccver'.")
+                                 "One of these must be present: 'qseqid', "
+                                 "'qacc', or 'qaccver'.")
 
     def __iter__(self):
-        """Iterates over the file handle; yields key, start offset, and length."""
+        """Iterate over the file handle; yields key, start offset, and length."""
         handle = self._handle
         handle.seek(0)
 
@@ -540,7 +555,7 @@ class BlastTabIndexer(SearchIndexer):
             yield _bytes_to_string(key), offset, length
 
     def _qresult_index_commented(self):
-        """Indexer for commented BLAST tabular files."""
+        """Indexer for commented BLAST tabular files (PRIVATE)."""
         handle = self._handle
         handle.seek(0)
         start_offset = 0
@@ -567,7 +582,7 @@ class BlastTabIndexer(SearchIndexer):
                 break
 
     def _qresult_index(self):
-        """Indexer for noncommented BLAST tabular files."""
+        """Indexer for noncommented BLAST tabular files (PRIVATE)."""
         handle = self._handle
         handle.seek(0)
         start_offset = 0
@@ -600,7 +615,7 @@ class BlastTabIndexer(SearchIndexer):
                 break
 
     def get_raw(self, offset):
-        """Returns the raw bytes string of a QueryResult object from the given offset."""
+        """Return the raw bytes string of a QueryResult object from the given offset."""
         if self._kwargs['comments']:
             getfunc = self._get_raw_qresult_commented
         else:
@@ -609,7 +624,7 @@ class BlastTabIndexer(SearchIndexer):
         return getfunc(offset)
 
     def _get_raw_qresult(self, offset):
-        """Returns the raw bytes string of a single QueryResult from a noncommented file."""
+        """Return the raw bytes string of a single QueryResult from a noncommented file (PRIVATE)."""
         handle = self._handle
         handle.seek(offset)
         qresult_raw = _as_bytes('')
@@ -636,7 +651,7 @@ class BlastTabIndexer(SearchIndexer):
         return qresult_raw
 
     def _get_raw_qresult_commented(self, offset):
-        """Returns the bytes raw string of a single QueryResult from a commented file."""
+        """Return the bytes raw string of a single QueryResult from a commented file (PRIVATE)."""
         handle = self._handle
         handle.seek(offset)
         qresult_raw = _as_bytes('')
@@ -662,16 +677,16 @@ class BlastTabIndexer(SearchIndexer):
 
 
 class BlastTabWriter(object):
-
     """Writer for blast-tab output format."""
 
     def __init__(self, handle, comments=False, fields=_DEFAULT_FIELDS):
+        """Initialize the class."""
         self.handle = handle
         self.has_comments = comments
         self.fields = fields
 
     def write_file(self, qresults):
-        """Writes to the handle, returns how many QueryResult objects are written."""
+        """Write to the handle, return how many QueryResult objects were written."""
         handle = self.handle
         qresult_counter, hit_counter, hsp_counter, frag_counter = 0, 0, 0, 0
 
@@ -697,7 +712,7 @@ class BlastTabWriter(object):
         return qresult_counter, hit_counter, hsp_counter, frag_counter
 
     def _build_rows(self, qresult):
-        """Returns a string containing tabular rows of the QueryResult object."""
+        """Return a string containing tabular rows of the QueryResult object (PRIVATE)."""
         coordinates = set(['qstart', 'qend', 'sstart', 'send'])
         qresult_lines = ''
         for hit in qresult:
@@ -745,7 +760,7 @@ class BlastTabWriter(object):
         return qresult_lines
 
     def _adjust_coords(self, field, value, hsp):
-        """Adjusts start and end coordinates according to strand."""
+        """Adjust start and end coordinates according to strand (PRIVATE)."""
         assert field in ('qstart', 'qend', 'sstart', 'send')
         # determine sequence type to operate on based on field's first letter
         seq_type = 'query' if field.startswith('q') else 'hit'
@@ -753,7 +768,7 @@ class BlastTabWriter(object):
         strand = getattr(hsp, '%s_strand' % seq_type, None)
         if strand is None:
             raise ValueError("Required attribute %r not found." %
-                    ('%s_strand' % (seq_type)))
+                             ('%s_strand' % (seq_type)))
         # switch start <--> end coordinates if strand is -1
         if strand < 0:
             if field.endswith('start'):
@@ -767,7 +782,7 @@ class BlastTabWriter(object):
         return value
 
     def _adjust_output(self, field, value):
-        """Adjusts formatting of the given field and value to mimic native tab output."""
+        """Adjust formatting of given field and value to mimic native tab output (PRIVATE)."""
         # qseq and sseq are stored as SeqRecord, but here we only need the str
         if field in ('qseq', 'sseq'):
             value = str(value.seq)
@@ -815,7 +830,7 @@ class BlastTabWriter(object):
 
         # list into ';'-delimited string
         elif field in ('sallseqid', 'sallacc', 'staxids', 'sscinames',
-                'scomnames', 'sblastnames', 'sskingdoms'):
+                       'scomnames', 'sblastnames', 'sskingdoms'):
             value = ';'.join(value)
 
         # everything else
@@ -825,7 +840,7 @@ class BlastTabWriter(object):
         return value
 
     def _build_comments(self, qres):
-        """Returns a string of a QueryResult tabular comment."""
+        """Return QueryResult tabular comment as a string (PRIVATE)."""
         comments = []
         # inverse mapping of the long-short name map, required
         # for writing comments
